summaryrefslogtreecommitdiff
path: root/nuttx/net/uip/uip_igmpgroup.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/net/uip/uip_igmpgroup.c')
-rw-r--r--nuttx/net/uip/uip_igmpgroup.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/nuttx/net/uip/uip_igmpgroup.c b/nuttx/net/uip/uip_igmpgroup.c
index a530f954c..6e2b37f1d 100644
--- a/nuttx/net/uip/uip_igmpgroup.c
+++ b/nuttx/net/uip/uip_igmpgroup.c
@@ -378,13 +378,13 @@ void uip_grpfree(FAR struct uip_driver_s *dev, FAR struct igmp_group_s *group)
else
#endif
{
/* No.. deallocate the group structure. Use sched_free() just in case
* this function is executing within an interrupt handler.
*/
uip_unlock(flags);
- grplldbg("Call sched_free()\n");
- sched_free(group);
+ grplldbg("Call sched_kfree()\n");
+ sched_kfree(group);
}
}
@@ -378,13 +378,13 @@ void uip_grpfree(FAR struct uip_driver_s *dev, FAR struct igmp_group_s *group)
#endif
{
- /* No.. deallocate the group structure. Use sched_free() just in case
+ /* No.. deallocate the group structure. Use sched_kfree() just in case
* this function is executing within an interrupt handler.
*/